var ahd__bayer_8c =
[
    [ "AD", "ahd__bayer_8c.html#a7e98848076c6c8edd529cd3b04beae8d", null ],
    [ "BLUE", "ahd__bayer_8c.html#a79d10e672abb49ad63eeaa8aaef57c38", null ],
    [ "CLAMP", "ahd__bayer_8c.html#aaefe6f014fd5125ca10cc315080003c7", null ],
    [ "GREEN", "ahd__bayer_8c.html#acfbc006ea433ad708fdee3e82996e721", null ],
    [ "MAX", "ahd__bayer_8c.html#aacc3ee1a7f283f8ef65cea31f4436a95", null ],
    [ "MIN", "ahd__bayer_8c.html#a74e75242132eaabbc1c512488a135926", null ],
    [ "RED", "ahd__bayer_8c.html#a8d23feea868a983c8c2b661e1e16972f", null ],
    [ "gp_ahd_decode", "ahd__bayer_8c.html#a0a10c31feb99742199ca9b8479809ee4", null ],
    [ "gp_ahd_interpolate", "ahd__bayer_8c.html#ad3e98332c40eea761faae753444cfcad", null ]
];